@@ -162,7 +162,7 @@ class CustomFormMixin:
                 else None,
                 for_form=True,
             )
-            declared_formfields = self.fields or direct_model_formfields
+            declared_formfields = list(self.fields or direct_model_formfields)
             inlineforms = {}
             for i, field in enumerate(list(declared_formfields)):
                 if isinstance(field, str) and "." in field:
@@ -180,13 +180,9 @@ class CustomFormMixin:
                 elif isinstance(field, str) and field in inlineforms:
                     ret.append(
                         layout.forms.Formset.as_datatable(
-                            hg.C(layout.forms.fields.DEFAULT_FORM_CONTEXTNAME)[
-                                field
-                            ].formset,
+                            hg.C("form")[field].formset,
                             fieldname=field,
-                            title=hg.C(layout.forms.fields.DEFAULT_FORM_CONTEXTNAME)[
-                                field
-                            ].label,
+                            title=hg.C("form")[field].label,
                             fields=inlineforms[field],
                             formsetfield_kwargs={
                                 "extra": 1,
